@@ -2,6 +2,9 @@ from base import MBillsBase
 from python_mbills.api import MBillsAPI
 from python_mbills.exceptions import SignatureValidationException
 
+from decimal import Decimal
+
+
 pub_key = """-----BEGIN PUBLIC KEY-----
  MIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA94CbbAspiut6qnC1iLzS
  JY4kmEgW/euPenOvMCB0EbbjSBVncx1Vi6UvbY86bu/3ZMgDBdhcq9fvqrdL2WLv
@@ -25,12 +28,17 @@ except SignatureValidationException:
 
 
 try:
-    transaction_id, payment_token_number, status = api.create_new_sale(100, 'Some purpose here')
-    print("Payment token number: %s" % payment_token_number)
+    #transaction_id, payment_token_number, status = api.create_new_sale(Decimal(1), 'Some purpose here', capture=False)
+    #print("Payment token number: %s" % payment_token_number)
+
+    transaction_id = '235253'
+    api.capture_sale(transaction_id, capture_amount=Decimal(1))
 
     transaction = api.fetch_transaction_status(transaction_id)
 
     print(transaction)
 
+
+
 except SignatureValidationException:
     print("Failed to verify signature")
